API docs for “spamfighter”

# Package spamfighter

View Source

СпамоБорец.

Веб-сервис для фильтрации спама в реальном времени.

Package | api | Набор команд, составляющих API СпамоБорца (`sf.*`).
Package | core | Ядро сервера: базовые классы команд, доменов, партнеров и т.п.
Module | interfaces | Базовые интерфейсы проекта.
Module | plugin | Подсистема плагинов СпамоБорца и интерфейсы плагинов.
Package | plugins | Базовый каталог плагинов.
Package | rules | Набор правил анализа сообщений СпамоБорца.
Package | scripts | Различные сервисные скрипты.
Module | service | Построение сервисов, составляющих ядро сервера.
Package | test | Тесты на `spamfighter`.
Package | txjsonrpc | No package docstring; 1/1 modules, 0/3 packages documented
Package | utils | Различные утилиты и вспомогательные классы.